//
//  X509CertificateGenerator.java
//
//  Modified by : Priyank Patel <pkpatel@cs.stanford.edu>
//                added the policies for the chat rooms A and B
//

package Chat;

import java.util.*;
import java.security.*;
import java.math.BigInteger;
import java.security.cert.CertificateException;

import iaik.security.rsa.*;
import iaik.x509.*;
import iaik.asn1.structures.*;
import iaik.asn1.*;
import iaik.x509.extensions.*;
import iaik.x509.extensions.netscape.NetscapeCertType;
import iaik.security.provider.IAIK;
import iaik.pkcs.pkcs8.*;
import iaik.utils.KeyAndCertificate;

public class X509CertificateGenerator {

  public static X509Certificate 
    generateCertificate(
			Principal subjectName,
			PublicKey subjectPublicKey,
			Principal issuerName,
			PrivateKey issuerPrivateKey,
			AlgorithmID algorithm,
			BigInteger serialNumber,
			boolean allowRoomA,
			boolean allowRoomB) {
 
    X509Extensions.register(RoomAExtension.oid,
			    RoomAExtension.class);
    X509Extensions.register(RoomBExtension.oid,
			    RoomBExtension.class);

    X509Certificate cert = new X509Certificate();
    
    try {
      
      cert.setSerialNumber(serialNumber);
      cert.setSubjectDN(subjectName);
      cert.setPublicKey(subjectPublicKey);
      cert.setIssuerDN(issuerName);
      
      GregorianCalendar date = new GregorianCalendar();
      date.add(Calendar.DATE, -1);
      cert.setValidNotBefore(date.getTime());   // not before yesterday
      
      date.add(Calendar.MINUTE, 30);            // crank this if you want
                                                // give more time
      cert.setValidNotAfter(date.getTime());

      //Set the policies
      BOOLEAN roomAaccess = new BOOLEAN(allowRoomA);
      BOOLEAN roomBaccess = new BOOLEAN(allowRoomB);
      RoomAExtension policyA = new RoomAExtension(roomAaccess);
      RoomBExtension policyB = new RoomBExtension(roomBaccess);
      
      cert.addExtension(policyA);
      cert.addExtension(policyB);

      cert.sign(algorithm, issuerPrivateKey);
      
    } catch (InvalidKeyException e) {
      
      System.out.println("X509 Certificate Generation Error: Invalid Key");
      e.printStackTrace();
      
    } catch (NoSuchAlgorithmException e) {
      
      System.out.println("X509 Certificate Generation Error: No Such Algorithm");
      e.printStackTrace();
      
    } catch (CertificateException e) {
      
      System.out.println("X509 Certificate Generation Error: Certificate Exception");
      e.printStackTrace();
    } catch (X509ExtensionException e) {
      
      System.out.println("X509 Certificate Generation Error: Certificate Exception");
      e.printStackTrace();
    }

    return cert;
    
  }
}
